AMYPAD Core
===========

|Versions| |Py-Versions| |Tests| |LICENCE|

Basic functionality needed for `AMYPAD <https://github.com/AMYPAD/AMYPAD>`_.


Install
-------

Intended for inclusion in requirements for other packages.
The package name is ``amypad-core``. Options include:

- nii

To install options and their dependencies,
use the package name ``amypad-core[option1,option2]``.


.. |Tests| image:: https://img.shields.io/github/workflow/status/AMYPAD/amypad-core/Test
   :target: https://github.com/AMYPAD/amypad-core/actions
.. |Versions| image:: https://img.shields.io/pypi/v/amypad-core.svg
   :target: https://github.com/amypad/amypad-core/releases
.. |Py-Versions| image:: https://img.shields.io/pypi/pyversions/amypad-core.svg?logo=python&logoColor=white
   :target: https://pypi.org/project/amypad-core
.. |LICENCE| image:: https://img.shields.io/pypi/l/amypad-core.svg
   :target: https://raw.githubusercontent.com/AMYPAD/amypad-core/master/LICENCE.md
